package collections.functors;

import java.io.Serializable;

import collections.Predicate;

/**
 * Predicate implementation that always returns true.
 * 
 */
public final class TruePredicate implements Predicate, Serializable {

    /** Serial version UID */
    private static final long serialVersionUID = 3374767158756189740L;
    
    /** Singleton predicate instance */
    public static final Predicate INSTANCE = new TruePredicate();

    /**
     * Factory returning the singleton instance.
     * 
     * @return the singleton instance
     */
    public static Predicate getInstance() {
        return INSTANCE;
    }

    /**
     * Restricted constructor.
     */
    private TruePredicate() {
        super();
    }

    /**
     * Evaluates the predicate returning true always.
     * 
     * @param object  the input object
     * @return true always
     */
    public boolean evaluate(Object object) {
        return true;
    }

}
