package collections.functors;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

import collections.Predicate;

/**
 * Predicate implementation that returns true the first time an object is
 * passed into the predicate.
 * 
 */
public final class UniquePredicate implements Predicate, Serializable {

    /** Serial version UID */
    private static final long serialVersionUID = -3319417438027438040L;
    
    /** The set of previously seen objects */
    private final Set iSet = new HashSet();
    
    /**
     * Factory to create the predicate.
     * 
     * @return the predicate
     * @throws IllegalArgumentException if the predicate is null
     */
    public static Predicate getInstance() {
        return new UniquePredicate();
    }

    /**
     * Constructor that performs no validation.
     * Use <code>getInstance</code> if you want that.
     */
    public UniquePredicate() {
        super();
    }

    /**
     * Evaluates the predicate returning true if the input object hasn't been
     * received yet.
     * 
     * @param object  the input object
     * @return true if this is the first time the object is seen
     */
    public boolean evaluate(Object object) {
        return iSet.add(object);
    }

}
